@@ -8,7 +8,7 @@
 
 
 extern Settings settings;
-extern QString iconPath;
+extern QString iconPath;    // FIXME-4 embed vym logo as ressource?
 extern QString vymVersion;
 extern QString vymBuildDate;
 extern QString vymCodeName;
@@ -23,7 +23,7 @@ AboutDialog::AboutDialog( QWidget *parent)
     credits=new AboutTextBrowser (parent);
 
     credits->setHtml( QString(
-    "<center><img src=\""+iconPath+"vym-128x128.png\"></center>"
+    "<center><img src=\"" + iconPath + "vym-128x128.png\"></center>"
     "<h3><center>VYM - View Your Mind </h3>"
     "<p align=\"center\"> A tool to put the things you have got in your mind into a map.</p>"
     "<p align=\"center\"> (c) 2004-%1 by Uwe Drechsel (<a href=\"mailto:vym@InSilmaril.de\">vym@InSilmaril.de</a>)</p>"
@@ -62,10 +62,12 @@ AboutDialog::AboutDialog( QWidget *parent)
     "    <li>Russian: Anton Olenev</li>"
     "    <li>Simplified Chinese: Moligaloo</li>"
     "    <li>Traditional Chinese: Wei-Lun Chao </li>"
+    "    <li>Japanese: Tsuren Tsuchiya</li>"
     "  </ul>"
     "</li>"
     "<li> Patches"
     "  <ul>"
+    "    <li>Darren Lissimore: Windows compiler patch </li>"
     "    <li>Konstantin Goudkov: sort branches</li>"
     "    <li>Jakob Hilmer: image drag and drop in 1.8.1, &quot;About vym&quot; window patch </li>"
     "    <li>Edward Wang: adding close tab buttons</li>"
@@ -74,6 +76,8 @@ AboutDialog::AboutDialog( QWidget *parent)
     "</li>"
     "<li> Patches in previous vym versions"
     "  <ul>"
+    "    <li>Łukasz Pietrzak, Scott Dillman and Patrick Spendrin, Andrew Ng, " 
+            "Juha Ruotsalainen and Thomas Kriener: windows patches</li>"
     "    <li>Thomas Schraitle for the stylesheet"  
     "        formerly used for XHTML-export and help with XML processing in general</li>"
     "    <li>Matt from <a href=\"http://www.satbp.com\">www.satbp.com</a>: "
@@ -83,9 +87,7 @@ AboutDialog::AboutDialog( QWidget *parent)
     "<li> Packaging"
     "</li>"
     "  <ul>"
-    "    <li>Scott Dillman and Patrick Spendrin: Recent windows patches</li>"
     "    <li>Jon Ciesla: Sourceforge file releases</li>"
-    "    <li>Andrew Ng, Juha Ruotsalainen and Thomas Kriener: Older windows patches</li>"
     "    <li>Xavier Oswald, Christoph Thielecke, Pierre, and Steffen Joeris: Debian packaging</li>"
     "  </ul>"
     "<li> General"
@@ -235,7 +237,7 @@ AboutTextBrowser::AboutTextBrowser(QWidget *parent)
 void AboutTextBrowser::setSource(const QUrl &url )
 {
     QProcess *proc= new QProcess ();
-    proc->start( settings.value("/mainwindow/readerURL").toString(),QStringList ()<<url.toString());
+    proc->start( settings.value("/system/readerURL").toString(),QStringList ()<<url.toString());
     //if (!proc->waitForStarted() &&mainWindow->settingsURL() ) setSource(url);
     if (!proc->waitForStarted() )
 	QMessageBox::warning(0, 
