@@ -23,9 +23,9 @@ BranchObj::BranchObj (QGraphicsItem *parent,TreeItem *ti):OrnamentedObj (parent,
     treeItem=ti;
     BranchItem *pi=(BranchItem*)(ti->parent());
     if (pi && pi!=ti->getModel()->getRootItem() )
-	parObj=pi->getLMO();
+        parObj=pi->getLMO();
     else
-	parObj=NULL;
+        parObj=NULL;
     init();
 }
 
@@ -36,9 +36,9 @@ BranchObj::~BranchObj ()
     // If I'm animated, I need to un-animate myself first
     if (anim.isAnimated() )
     {
-	anim.setAnimated (false);
-	VymModel *model=treeItem->getModel();
-	model->stopAnimation (this);
+        anim.setAnimated (false);
+        VymModel *model=treeItem->getModel();
+        model->stopAnimation (this);
     }
 
     clear();
@@ -65,7 +65,7 @@ void BranchObj::clear()
 void BranchObj::setParObjTmp(LinkableMapObj* dst, QPointF m, int off)	
 {
     // Temporary link to dst
-    // m is position of mouse pointer 
+    // m is position of mouse pointer
     // offset 0: default 1: below dst   -1 above dst  (if possible)
 
     BranchItem *dsti=(BranchItem*)(dst->getTreeItem());
@@ -74,84 +74,83 @@ void BranchObj::setParObjTmp(LinkableMapObj* dst, QPointF m, int off)
     int pi_depth=pi->depth();
     BranchObj* bodst=(BranchObj*)dst;
 
-    if (!tmpParent) 
+    if (!tmpParent)
     {
-	tmpParent=true;
-	parObjTmpBuf=parObj;
+        tmpParent=true;
+        parObjTmpBuf=parObj;
     }
 
     if (pi_depth<1) off=0;
     if (off==0)
-	link2ParPos=false;
+        link2ParPos=false;
     else
-	link2ParPos=true;
+        link2ParPos=true;
     parObj=bodst;
 
     setLinkStyle (dst->getDefLinkStyle (dsti));
- 
+
     // Move temporary to new position at destination
     // Usually the positioning would be done by reposition(),
     // but then also the destination branch would "Jump" around...
     // Better just do it approximately
-    if (dsti->depth()==0)   
+    if (dsti->depth()==0)
     {	// new parent is a mapcenter
-	Vector v= ( m - bodst->getChildRefPos());
-	v.normalize();
-	v.scale (150);
-	move2RelPos (v.toQPointF());
+        Vector v= ( m - bodst->getChildRefPos());
+        v.normalize();
+        v.scale (150);
+        move2RelPos (v.toQPointF());
     } else
-    {	
-	qreal y;
-	if (off==0)
-	{
-		// Below is needed e.g. in a freshly loaded map, 
-		// bboxTotal seems not to be correct yet
-		// relinking positions too far below then
-		calcBBoxSizeWithChildren(); 
+    {
+        qreal y;
+        if (off==0)
+        {
+            // Below is needed e.g. in a freshly loaded map,
+            // bboxTotal seems not to be correct yet
+            // relinking positions too far below then
+            calcBBoxSizeWithChildren();
 
-	    // new parent is just a branch, link to it
-	    bodst->calcBBoxSizeWithChildren();	
-	    QRectF t=bodst->getTotalBBox();
-	    if (dsti->getLastBranch())
-		y=t.y() + t.height() ;
-	    else
-		y=t.y();
-
-	    y=t.bottom();
-
-	} else
-	{
-	    if (off<0)
-		// we want to link above dst
-		y=bodst->y() - height() + 12;
-	    else    
-		// we want to link below dst
-		// Bottom of sel should be 5 pixels above
-		// the bottom of the branch _below_ the target:
-		// Don't try to find that branch, guess 12 pixels
-		y=bodst->getChildRefPos().y()  -height() + 12; 
-	}   
-	if (bodst->getOrientation()==LinkableMapObj::LeftOfCenter)
-	    move ( bodst->getChildRefPos().x() - linkwidth, y );
-	else	
-	    move (bodst->getChildRefPos().x() + linkwidth, y );
-    }	
+            // new parent is just a branch, link to it
+            bodst->calcBBoxSizeWithChildren();
+            QRectF t = bodst->getTotalBBox();
+            if (dsti->getLastBranch())
+                // Move below children of destination
+                y = t.y() + t.height() ;
+            else
+                // Move left or right to destination
+                y = t.y()  ;
+        } else
+        {
+            if (off < 0)
+                // we want to link above dst
+                y = bodst->y() - height() + 12;
+            else
+                // we want to link below dst
+                // Bottom of sel should be 5 pixels above
+                // the bottom of the branch _below_ the target:
+                // Don't try to find that branch, guess 12 pixels
+                y = bodst->getChildRefPos().y()  -height() + 12;
+        }
+        if (bodst->getOrientation()==LinkableMapObj::LeftOfCenter)
+            move ( bodst->getChildRefPos().x() - linkwidth - bboxTotal.width(), y );    
+        else
+            move ( bodst->getChildRefPos().x() + linkwidth, y );
+    }
 
     // updateLinkGeometry is called implicitly in move
-    requestReposition();    
+    requestReposition();
 }
 
 void BranchObj::unsetParObjTmp()
 {
-    if (tmpParent) 
+    if (tmpParent)
     {
-	tmpParent=false;
-	link2ParPos=false;
-	parObj=parObjTmpBuf;
-	parObjTmpBuf=NULL;
-	setLinkStyle (getDefLinkStyle(treeItem->parent() ) );
-	updateLinkGeometry();
-    }	    
+        tmpParent=false;
+        link2ParPos=false;
+        parObj=parObjTmpBuf;
+        parObjTmpBuf=NULL;
+        setLinkStyle (getDefLinkStyle(treeItem->parent() ) );
+        updateLinkGeometry();
+    }
 }
 
 void BranchObj::setVisibility(bool v, int toDepth) 
@@ -159,25 +158,25 @@ void BranchObj::setVisibility(bool v, int toDepth)
     BranchItem *bi=(BranchItem*)treeItem;
     if (bi->depth() <= toDepth)
     {
-	frame->setVisibility(v);
-	heading->setVisibility(v);
-	systemFlags->setVisibility(v);
-	standardFlags->setVisibility(v);
-	LinkableMapObj::setVisibility (v);
-	int i;
-	for (i=0; i<treeItem->imageCount(); ++i)
-	    treeItem->getImageObjNum(i)->setVisibility (v);
-	for (i=0; i<treeItem->xlinkCount(); ++i)    
-	    treeItem->getXLinkObjNum(i)->setVisibility ();  
+        frame->setVisibility(v);
+        heading->setVisibility(v);
+        systemFlags->setVisibility(v);
+        standardFlags->setVisibility(v);
+        LinkableMapObj::setVisibility (v);
+        int i;
+        for (i=0; i<treeItem->imageCount(); ++i)
+            treeItem->getImageObjNum(i)->setVisibility (v);
+        for (i=0; i<treeItem->xlinkCount(); ++i)
+            treeItem->getXLinkObjNum(i)->setVisibility ();
 
-	// Only change children, if I am not scrolled
-	if (! bi->isScrolled() && (bi->depth() < toDepth))
-	{
-	    // Now go recursivly through all children 
-	    for (i=0; i<treeItem->branchCount(); ++i)
-		treeItem->getBranchObjNum(i)->setVisibility (v,toDepth);    
-	}
-    } 
+        // Only change children, if I am not scrolled
+        if (! bi->isScrolled() && (bi->depth() < toDepth))
+        {
+            // Now go recursivly through all children
+            for (i=0; i<treeItem->branchCount(); ++i)
+                treeItem->getBranchObjNum(i)->setVisibility (v,toDepth);
+        }
+    }
 }   
 
 void BranchObj::setVisibility(bool v)
@@ -194,11 +193,11 @@ void BranchObj::setLinkColor ()
     VymModel *model=treeItem->getModel();
     if (model)
     {
-	if (model->getMapLinkColorHint()==HeadingColor)
-	    LinkableMapObj::setLinkColor (heading->getColor() );
-	else	
-	    LinkableMapObj::setLinkColor ();
-    }	    
+        if (model->getMapLinkColorHint()==HeadingColor)
+            LinkableMapObj::setLinkColor (heading->getColor() );
+        else
+            LinkableMapObj::setLinkColor ();
+    }
 }
 
 void BranchObj::positionContents()
@@ -206,7 +205,7 @@ void BranchObj::positionContents()
     OrnamentedObj::positionContents();
     updateLinkGeometry();// required before positioning images
     for (int i=0; i<treeItem->imageCount(); ++i)
-	treeItem->getImageObjNum(i)->reposition();
+        treeItem->getImageObjNum(i)->reposition();
 }
 
 void BranchObj::move (double x, double y)
@@ -236,15 +235,15 @@ void BranchObj::positionBBox() // FIXME-2 consider dimensions of frame (thicknes
 {
     QPointF ap=getAbsPos();
     bbox.moveTopLeft (ap);
-    positionContents();   // this positions FIOs  
+    positionContents();   // this positions FIOs
 
-    //Update links to other branches	
+    //Update links to other branches
     XLinkObj *xlo;
-    for (int i=0; i<treeItem->xlinkCount(); ++i)    
+    for (int i=0; i<treeItem->xlinkCount(); ++i)
     {
-	xlo=treeItem->getXLinkObjNum(i);
-	if (xlo) xlo->updateXLink();
-    }	
+        xlo=treeItem->getXLinkObjNum(i);
+        if (xlo) xlo->updateXLink();
+    }
 }
 
 void BranchObj::calcBBoxSize()
@@ -331,43 +330,42 @@ void BranchObj::setDockPos()
 {
     floatRefPos=ornamentsBBox.center();
 
-    if (treeItem->getType()==TreeItem::MapCenter)
+    if (treeItem->getType() == TreeItem::MapCenter)
     {
-	// set childRefPos to middle of MapCenterObj
-	QRectF r=clickPoly.boundingRect();
-	childRefPos.setX( r.topLeft().x() + r.width()/2 );
-	childRefPos.setY( r.topLeft().y() + r.height()/2 );
-	parPos=childRefPos;	
-	for (int i=0; i<treeItem->branchCount(); ++i)
-	    treeItem->getBranchObjNum(i)->updateLinkGeometry();
-
+        // set childRefPos to middle of MapCenterObj
+        QRectF r=clickPoly.boundingRect();
+        childRefPos.setX( r.topLeft().x() + r.width()/2 );
+        childRefPos.setY( r.topLeft().y() + r.height()/2 );
+        parPos=childRefPos;
+        for (int i=0; i<treeItem->branchCount(); ++i)
+            treeItem->getBranchObjNum(i)->updateLinkGeometry();
     } else
     {
-	if (orientation==LinkableMapObj::LeftOfCenter )
-	{
+        if (orientation == LinkableMapObj::LeftOfCenter )
+        {
             // Left of center
-	    if ( ((BranchItem*)treeItem)->getFrameIncludeChildren() )
-	    {
-		childRefPos=QPointF (ornamentsBBox.bottomLeft().x() - leftPad,  bottomlineY);
-		parPos=QPointF   (bboxTotal.bottomRight().x()-frame->getPadding()/2, bottomlineY);
-	    } else	
-	    {
-		childRefPos=QPointF (ornamentsBBox.bottomLeft().x() - frame->getPadding(),  bottomlineY);
-		parPos=QPointF   (ornamentsBBox.bottomRight().x(), bottomlineY);
-	    }
-	} else
-	{
+            if ( ((BranchItem*)treeItem)->getFrameIncludeChildren() )
+            {
+                childRefPos=QPointF (ornamentsBBox.bottomLeft().x() - leftPad,  bottomlineY);
+                parPos=QPointF   (bboxTotal.bottomRight().x()-frame->getPadding()/2, bottomlineY);
+            } else
+            {
+                childRefPos=QPointF (ornamentsBBox.bottomLeft().x() - frame->getPadding(),  bottomlineY);
+                parPos=QPointF   (ornamentsBBox.bottomRight().x(), bottomlineY);
+            }
+        } else
+        {
             // Right of center
-	    if ( ((BranchItem*)treeItem)->getFrameIncludeChildren() )
-	    {
-		childRefPos=QPointF(ornamentsBBox.bottomRight().x() + rightPad , bottomlineY);
-		parPos=QPointF ( bboxTotal.bottomLeft().x()+frame->getPadding()/2,  bottomlineY);
-	    } else	
-	    {
-		childRefPos=QPointF(ornamentsBBox.bottomRight().x() + frame->getPadding(), bottomlineY);
-		parPos=QPointF ( ornamentsBBox.bottomLeft().x(),  bottomlineY);
-	    }
-	}
+            if ( ((BranchItem*)treeItem)->getFrameIncludeChildren() )
+            {
+                childRefPos=QPointF(ornamentsBBox.bottomRight().x() + rightPad , bottomlineY);
+                parPos=QPointF ( bboxTotal.bottomLeft().x()+frame->getPadding()/2,  bottomlineY);
+            } else
+            {
+                childRefPos=QPointF(ornamentsBBox.bottomRight().x() + frame->getPadding(), bottomlineY);
+                parPos=QPointF ( ornamentsBBox.bottomLeft().x(),  bottomlineY);
+            }
+        }
     }
 }
 
@@ -375,47 +373,47 @@ void BranchObj::updateData()
 {
     if (!treeItem)
     {
-	qWarning ("BranchObj::udpateHeading treeItem==NULL");
-	return;
+        qWarning ("BranchObj::udpateHeading treeItem==NULL");
+        return;
     }
-    QString s=treeItem->getHeading();
-    if (s!=heading->text()) heading->setText (s);
+    QString s = treeItem->getHeadingText();
+    if ( s!=heading->text()) heading->setText (s);
 
     QStringList TIactiveFlags=treeItem->activeStandardFlagNames();
 
     // Add missing standard flags active in TreeItem
     for (int i=0;i<=TIactiveFlags.size()-1;i++)
-    {	
-	if (!standardFlags->isActive (TIactiveFlags.at(i) ))
-	{
-	    Flag *f=standardFlagsMaster->getFlag(TIactiveFlags.at(i));
-	    if (f) standardFlags->activate (f);
-	}
+    {
+        if (!standardFlags->isActive (TIactiveFlags.at(i) ))
+        {
+            Flag *f=standardFlagsMaster->getFlag(TIactiveFlags.at(i));
+            if (f) standardFlags->activate (f);
+        }
     }
     // Remove standard flags no longer active in TreeItem
     QStringList BOactiveFlags=standardFlags->activeFlagNames();
     for (int i=0;i<BOactiveFlags.size();++i)
-	if (!TIactiveFlags.contains (BOactiveFlags.at(i)))
-	    standardFlags->deactivate (BOactiveFlags.at(i));
+        if (!TIactiveFlags.contains (BOactiveFlags.at(i)))
+            standardFlags->deactivate (BOactiveFlags.at(i));
 
     // Add missing system flags active in TreeItem
     TIactiveFlags=treeItem->activeSystemFlagNames();
     for (int i=0;i<TIactiveFlags.size();++i)
-    {	
-	if (!systemFlags->isActive (TIactiveFlags.at(i) ))
-	{
-	    Flag *f=systemFlagsMaster->getFlag(TIactiveFlags.at(i));
-	    if (f) systemFlags->activate (f);
-	}
+    {
+        if (!systemFlags->isActive (TIactiveFlags.at(i) ))
+        {
+            Flag *f=systemFlagsMaster->getFlag(TIactiveFlags.at(i));
+            if (f) systemFlags->activate (f);
+        }
     }
     // Remove system flags no longer active in TreeItem
     BOactiveFlags=systemFlags->activeFlagNames();
     for (int i=0;i<BOactiveFlags.size();++i)
     {
-	if (!TIactiveFlags.contains (BOactiveFlags.at(i)))
-	    systemFlags->deactivate (BOactiveFlags.at(i));
+        if (!TIactiveFlags.contains (BOactiveFlags.at(i)))
+            systemFlags->deactivate (BOactiveFlags.at(i));
     }
-    calcBBoxSize(); 
+    calcBBoxSize();
 }
 
 void BranchObj::setDefAttr (BranchModification mod, bool keepFrame)
@@ -424,18 +422,18 @@ void BranchObj::setDefAttr (BranchModification mod, bool keepFrame)
     qreal fontsize=font.pointSizeF();
     switch (treeItem->depth())
     {
-	case 0: 
-	    break;
-	case 1: 
-	    fontsize=fontsize-2; 
-	    break;
-	case 2: 
-	    fontsize=fontsize-4; 
-	    break;
-	default: 
-	    fontsize=fontsize-6; 
-	    break;
-    }	
+    case 0:
+        break;
+    case 1:
+        fontsize=fontsize-2;
+        break;
+    case 2:
+        fontsize=fontsize-4;
+        break;
+    default:
+        fontsize=fontsize-6;
+        break;
+    }
     setLinkStyle(getDefLinkStyle(treeItem->parent() ));
     setLinkColor ();
     font.setPointSizeF (fontsize);
@@ -443,23 +441,23 @@ void BranchObj::setDefAttr (BranchModification mod, bool keepFrame)
 
     if (mod==NewBranch && !keepFrame)
     {
-	if (treeItem->depth()==0)
-	    setFrameType (FrameObj::Rectangle);
-	else	
-	    setFrameType (FrameObj::NoFrame);
+        if (treeItem->depth()==0)
+            setFrameType (FrameObj::Rectangle);
+        else
+            setFrameType (FrameObj::NoFrame);
     }
     if (mod==NewBranch)
-	setColor (treeItem->getHeadingColor() );
+        setColor (treeItem->getHeadingColor() );
     else
     {
-	// Relinked mapcenters
-	if (!keepFrame && getFrameType()!=FrameObj::NoFrame)
-	    setFrameType (FrameObj::NoFrame);
+        // Relinked mapcenters
+        if (!keepFrame && getFrameType()!=FrameObj::NoFrame)
+            setFrameType (FrameObj::NoFrame);
 
-	// Also set styles for children
-	for (int i=0; i<treeItem->branchCount(); ++i)
-	    treeItem->getBranchObjNum(i)->setDefAttr(MovedBranch, keepFrame);
-    }	    
+        // Also set styles for children
+        for (int i=0; i<treeItem->branchCount(); ++i)
+            treeItem->getBranchObjNum(i)->setDefAttr(MovedBranch, keepFrame);
+    }
     calcBBoxSize();
 }
 
@@ -471,9 +469,34 @@ void BranchObj::alignRelativeTo (QPointF ref,bool alignSelf)
     for (int i=0; i<treeItem->branchCount(); ++i)
         ch+=treeItem->getBranchObjNum(i)->getTotalBBox().height();
 
-    int depth=0;
-    if (parObj)	depth=1 + parObj->getTreeItem()->depth();
+    int depth = 0;
+    BranchItem::LayoutHint layoutHint = BranchItem::AutoPositioning;
+    if (parObj)
+    {
+        TreeItem *pi = parObj->getTreeItem();
+        depth = 1 + pi->depth();
+        layoutHint = ((BranchItem*)treeItem)->parentBranch()->getChildrenLayout();
+    }
     
+    // set useRelPos, depending on layout
+    if (depth > 1)
+    {
+        if (layoutHint == BranchItem::FreePositioning)
+        {
+            if (!useRelPos) 
+            {
+                useRelPos = true;
+                // if we used relPos before, set known positions
+                // "known" means any position != (0,0)
+                if (relPos == QPointF(0,0) )
+                    // use current position to get relPos()
+                    setRelPos();
+            }
+        }
+        else
+            useRelPos = false;
+    }
+
 // TODO testing
 /*
     if (debug)
@@ -481,18 +504,18 @@ void BranchObj::alignRelativeTo (QPointF ref,bool alignSelf)
         QString o;
         switch (orientation)
         {	
-            case UndefinedOrientation: o="UndefOrientation";
-            case LeftOfCenter: o="LeftOfCenter";
-            case RightOfCenter: o="RightOfCenter";
+            case UndefinedOrientation: o = "UndefOrientation"; break;
+            case LeftOfCenter: o = "LeftOfCenter"; break;
+            case RightOfCenter: o = "RightOfCenter"; break;
         }
             
         QString h=QString (depth+1,' ');
-        h+=treeItem->getHeading();
-        h+=QString (15,' ');
-        h.truncate (15);
+        h += treeItem->getHeadingPlain();
+        h += QString (25,' ');
+        h.truncate (25);
         QPointF pp; 
-        if (parObj) pp=parObj->getChildRefPos();
-        qDebug() << "BO::alignRelTo for "<<h;
+        if (parObj) pp = parObj->getChildRefPos();
+        qDebug() << "BO::alignRelTo for "<<h
     //    qDebug() << "    d="<<depth;
     //    qDebug() <<"   ref="<<ref;
     //    qDebug() <<"    th="<<th;
@@ -500,11 +523,12 @@ void BranchObj::alignRelativeTo (QPointF ref,bool alignSelf)
     //    if (ch < th) qDebug()<<"   ch<th !";
     //    qDebug() <<"  parO="<<parObj;
         //qDebug() <<   "  bbox.tL="<<bboxTotal.topLeft();
+        << "  useRelPos=" << useRelPos 
     //    qDebug() <<"absPos="<<absPos
     //	<< "  relPos="<<relPos
     //	<< "  parPos="<<pp
     //	<< "  bbox="<<bbox
-    //	<< "  orient="<<o<<" "<<orientation;
+    	<< "  orient="<<o<<" "<<orientation;
     //	<< "  alignSelf="<<alignSelf
     //	<< "  scrolled="<<((BranchItem*)treeItem)->isScrolled()
     //	<< "  pad="<<topPad<<","<<botPad<<","<<leftPad<<","<<rightPad
@@ -521,29 +545,33 @@ void BranchObj::alignRelativeTo (QPointF ref,bool alignSelf)
     if (depth==0)
         move (getAbsPos()); // Trigger update of frames etc.
     else if(depth==1)
-	move2RelPos (getRelPos() );
+        move2RelPos (getRelPos() );
     else if (depth>1)
     {
-	if (anim.isAnimated())
-	    move2RelPos(anim);
-	else
-	{
-	    if (alignSelf)
-		switch (orientation) 
-		{
-		    case LinkableMapObj::LeftOfCenter:
-			move (ref.x() - bbox.width(), ref.y() + (th-bbox.height())/2 );
-		    break;
-		    case LinkableMapObj::RightOfCenter:	
-			move (ref.x() , ref.y() + (th - bbox.height())/2 );
-			//move (ref.x() , ref.y() );
-		    break;
-		    default:
-			qWarning ("LMO::alignRelativeTo: oops, no orientation given for BO...");
-		    break;
-	    }
-	}
-    }	    
+        if (layoutHint == BranchItem::FreePositioning)
+            move2RelPos (getRelPos() );
+        else
+        {
+            if (anim.isAnimated())
+                move2RelPos(anim);
+            else
+            {
+                if (alignSelf)
+                    switch (orientation)
+                    {
+                    case LinkableMapObj::LeftOfCenter:
+                        move (ref.x() - bbox.width(), ref.y() + (th-bbox.height())/2 );
+                        break;
+                    case LinkableMapObj::RightOfCenter:
+                        move (ref.x() , ref.y() + (th - bbox.height())/2 );
+                        break;
+                    default:
+                        qWarning ("LMO::alignRelativeTo: oops, no orientation given for BO...");
+                        break;
+                    }
+            }
+        }
+    }
 
     // Without ancestors I am done
     if ( ((BranchItem*)treeItem)->isScrolled() ) return;
@@ -551,31 +579,31 @@ void BranchObj::alignRelativeTo (QPointF ref,bool alignSelf)
     // Set reference point for alignment of children
     QPointF ref2;
     if (orientation==LinkableMapObj::LeftOfCenter)
-	ref2.setX(childRefPos.x() - linkwidth);
-    else    
-	ref2.setX(childRefPos.x() + linkwidth);
+        ref2.setX(childRefPos.x() - linkwidth);
+    else
+        ref2.setX(childRefPos.x() + linkwidth);
 
     if (depth==1)
-	ref2.setY (absPos.y() + (bbox.height() - ch)/2);
-    else    
+        ref2.setY (absPos.y() + (bbox.height() - ch)/2);
+    else
     {
         if (ch > th)
-            ref2.setY (ref.y() + frame->getPadding());  
+            ref2.setY (ref.y() + frame->getPadding());
         else
             // Parent is bigger than all of childs, center childs vertically
             ref2.setY (ref.y() + (th - ch)/2 );
     }
 
-    // Align the branch children depending on reference point 
+    // Align the branch children depending on reference point
     for (int i=0; i<treeItem->branchCount(); ++i)
-    {	
-	if (!treeItem->getBranchNum(i)->isHidden())
-	{
-	    treeItem->getBranchObjNum(i)->alignRelativeTo (ref2,true);
+    {
+        if (!treeItem->getBranchNum(i)->isHidden())
+        {
+            treeItem->getBranchObjNum(i)->alignRelativeTo (ref2,true);
 
-	    // append next branch below current one
-	    ref2.setY(ref2.y() + treeItem->getBranchObjNum(i)->getTotalBBox().height() );
-	}
+            // append next branch below current one
+            ref2.setY(ref2.y() + treeItem->getBranchObjNum(i)->getTotalBBox().height() );
+        }
     }
 }
 
@@ -605,7 +633,7 @@ void BranchObj::unsetAllRepositionRequests()
 {
     repositionRequest=false;
     for (int i=0; i<treeItem->branchCount(); ++i)
-	treeItem->getBranchObjNum(i)->unsetAllRepositionRequests();
+        treeItem->getBranchObjNum(i)->unsetAllRepositionRequests();
 }
 
 QRectF BranchObj::getTotalBBox()
@@ -617,9 +645,9 @@ ConvexPolygon BranchObj::getBoundingPolygon()
 {
     if (treeItem->branchCount()==0 || treeItem->depth()==0)
     {
-	if (boundingPolygon) 
-	    boundingPolygon->setPolygon (MapObj::getBoundingPolygon() );
-	return MapObj::getBoundingPolygon();
+        if (boundingPolygon)
+            boundingPolygon->setPolygon (MapObj::getBoundingPolygon() );
+        return MapObj::getBoundingPolygon();
     }
 
     QPolygonF p;
@@ -635,47 +663,47 @@ void BranchObj::calcBBoxSizeWithChildren()
 {   
     // if branch is scrolled, ignore children, but still consider floatimages
     BranchItem *bi=(BranchItem*)treeItem;
-    if ( bi->isScrolled() ) 
+    if ( bi->isScrolled() )
     {
-	bboxTotal.setWidth (bbox.width());
-	bboxTotal.setHeight(bbox.height());
-	return;
+        bboxTotal.setWidth (bbox.width());
+        bboxTotal.setHeight(bbox.height());
+        return;
     }
     
     if (bi->isHidden())
     {
-	bboxTotal.setWidth (0);
-	bboxTotal.setHeight(0);
-	return;
+        bboxTotal.setWidth (0);
+        bboxTotal.setHeight(0);
+        return;
     }
     
     QRectF r(0,0,0,0);
     QRectF br;
 
-    // Now calculate 
-    // sum of heights 
-    // maximum of widths 
+    // Now calculate
+    // sum of heights
+    // maximum of widths
     // minimum of y
     for (int i=0; i<treeItem->branchCount(); i++)
     {
-	if (!bi->getBranchNum(i)->isHidden())
-	{
-	    BranchObj *bo=bi->getBranchObjNum(i);
-	    bo->calcBBoxSizeWithChildren();
-	    br=bo->getTotalBBox();
-	    r.setWidth( max (br.width(), r.width() ));
-	    r.setHeight(br.height() + r.height() );
-	}
+        if (!bi->getBranchNum(i)->isHidden())
+        {
+            BranchObj *bo=bi->getBranchObjNum(i);
+            bo->calcBBoxSizeWithChildren();
+            br=bo->getTotalBBox();
+            r.setWidth( max (br.width(), r.width() ));
+            r.setHeight(br.height() + r.height() );
+        }
     }
 
     // Add myself and also
     // add width of link to sum if necessary
     if (bi->branchCount()<1)
-	bboxTotal.setWidth (bbox.width() + r.width()  );
-    else    
-	bboxTotal.setWidth (bbox.width() + r.width() + linkwidth );
+        bboxTotal.setWidth (bbox.width() + r.width()  );
+    else
+        bboxTotal.setWidth (bbox.width() + r.width() + linkwidth );
     
-    // bbox already contains frame->padding()*2	    
+    // bbox already contains frame->padding()*2
     bboxTotal.setHeight(max (r.height() + frame->getPadding()*2,  bbox.height()) );
 }
 
@@ -688,9 +716,9 @@ void BranchObj::stopAnimation()
 {
     anim.stop();
     if (useRelPos)
-	setRelPos (anim);
+        setRelPos (anim);
     else
-	move (anim);
+        move (anim);
 }
 
 bool BranchObj::animate()
@@ -698,11 +726,11 @@ bool BranchObj::animate()
     anim.animate ();
     if ( anim.isAnimated() )
     {
-	if (useRelPos)
-	    setRelPos (anim);
-	else
-	    move (anim);
-	return true;
+        if (useRelPos)
+            setRelPos (anim);
+        else
+            move (anim);
+        return true;
     }
     return false;
 }
