@@ -7,11 +7,7 @@
 
 extern Settings settings;
 extern QDir vymBaseDir;
-
-QString Macros::getBasePath ()
-{
-    return settings.value ("macros/macroDir",vymBaseDir.path()+"/macros").toString();
-}
+extern QString macroPath;
 
 QString Macros::getPath (const int &i)
 {
@@ -30,13 +26,13 @@ QString Macros::getPath (const int &i)
         prefix="s";
         n=i-12;
     }
-    return getBasePath() + QString("/macro-%1%2%3.vys").arg(prefix).arg(pad).arg(n);
+    return macroPath + QString("macro-%1%2%3.vys").arg(prefix).arg(pad).arg(n);
 }
 
 QString Macros::getMacro (const int &i)    
 {
-
     QString fn=getPath(i);
+
     QFile f (fn);
     if ( !f.open( QIODevice::ReadOnly ) )
     {
@@ -44,10 +40,10 @@ QString Macros::getMacro (const int &i)
                 QObject::tr("Couldn't find a macro at  %1.\n").arg(fn)+
                 QObject::tr("Please use Settings->")+QObject::tr("Set directory for vym macros");
         return QString();
-    }   
+    }
 
     QTextStream ts( &f );
     QString macro= ts.readAll();
 
-    return macro;
+   return macro;
 }
