@@ -1,7 +1,8 @@
-#ifndef MAINWINDOW_H 
+#ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
 #include <QMainWindow>
+#include <QProgressDialog>
 
 #include "branchpropeditor.h"
 #include "extrainfodialog.h"
@@ -9,7 +10,6 @@
 #include "file.h"
 #include "historywindow.h"
 #include "mapeditor.h"
-#include "shortcuts.h"
 #include "texteditor.h"
 #include "vymview.h"
 
@@ -26,7 +26,7 @@ public:
 	ModModeXLink	//!< Create a XLink (XLinkObj) from selected object
 	};
 
-    Main(QWidget* parent=0, Qt::WFlags f=0);
+    Main(QWidget* parent=0, Qt::WindowFlags f=0);
     ~Main();
     void loadCmdLine();
 
@@ -84,7 +84,7 @@ public:
     int modelCount();
     
 private slots:
-    void editorChanged(QWidget*);
+    void editorChanged();
 
     File::ErrorCode fileLoad(QString ,const LoadMode &, const FileType &ftype);
     void fileLoad(const LoadMode &);
@@ -114,6 +114,7 @@ private slots:
     void fileExportSVG();
     void fileExportAO();
     void fileExportASCII();
+    void fileExportASCIITasks();
     void fileExportCSV();
     void fileExportOrgMode();
     void fileExportLaTeX();
@@ -121,8 +122,7 @@ private slots:
     void fileExportTaskjuggler();
     void fileExportImpress();
     void fileExportLast();
-    bool closeTab(int i);
-    bool fileCloseMap();
+    bool fileCloseMap(int i = -1);  // Optionally pass number of tab
     void filePrint();
     bool fileExitVYM();
 
@@ -245,8 +245,10 @@ public slots:
 public slots:
     void networkStartServer();
     void networkConnect();
+    void downloadFinished();
     bool settingsPDF();
     bool settingsURL();
+    void settingsZipTool();
     void settingsMacroDir();
     void settingsUndoLevels();
 
@@ -257,9 +259,10 @@ public:
 public slots:
     void settingsAutosaveTime();
     void settingsTaskShowParentsLevel();
-    void settingsAutoLayoutToggle();
-    void settingsWriteBackupFileToggle();
+    void settingsToggleAutoLayout();
+    void settingsToggleWriteBackupFile();
     void settingsToggleAnimation();
+    void settingsToggleDownloads();
 
     void windowToggleNoteEditor();
     void windowToggleTreeEditor();
@@ -268,6 +271,8 @@ public slots:
     void windowToggleScriptEditor();
     void windowToggleHistory();
     void windowToggleProperty();
+    void windowShowHeadingEditor();
+    void windowToggleHeadingEditor();
     void updateHistory(SimpleSettings &);
     void windowToggleAntiAlias();
 public:
@@ -279,6 +284,7 @@ public slots:
     void updateNoteFlag();
     void updateNoteEditor (QModelIndex index);
     void selectInNoteEditor (QString s, int i);
+    void setFocusMapEditor();
     void changeSelection (VymModel *model,const QItemSelection &newSel, const QItemSelection &delSel);
 
     void updateActions();
@@ -311,8 +317,19 @@ private slots:
     void helpAboutQT();
 
     void callMacro ();
+    void downloadReleaseNotesFinished(bool interactive=false);
+    void downloadReleaseNotesFinishedInt();
+
+public slots:
+    void checkReleaseNotes();
+    bool downloadsEnabled(bool interactive=false);
+    void downloadUpdatesFinished(bool interactive=false);
+    void downloadUpdatesFinishedInt();
+    void downloadUpdates(bool interactive);
+    void checkUpdates();
 
 private:
+    QString shortcutScope;          //! For listing shortcuts
     QTabWidget *tabWidget;
     qint64 *browserPID;
 
@@ -344,8 +361,6 @@ private:
     QAction *macroActions[13];
     QStringList macro;
 
-    Switchboard switchboard;
-
     QMenu *toolbarsMenu;
     QToolBar *fileToolbar;
     QToolBar *clipboardToolbar;
@@ -361,6 +376,7 @@ private:
     QAction* actionFileNew;
     QAction* actionFileNewCopy;
     QAction* actionFileOpen;
+    QAction* actionFileRestoreSession;
     QAction* actionFileSave;
     QAction* actionFilePrint;
     QAction* actionFileExportLast;
@@ -493,11 +509,12 @@ private:
     QAction* actionSettingsAutoSelectText;
     QAction* actionSettingsUseFlagGroups;
     QAction* actionSettingsUseHideExport;
-    QAction* actionSettingsAutosaveToggle;
+    QAction* actionSettingsToggleAutosave;
     QAction* actionSettingsAutosaveTime;
     QAction* actionSettingsTaskShowParentsLevel;
-    QAction* actionSettingsAutoLayoutToggle;
+    QAction* actionSettingsToggleAutoLayout;
     QAction* actionSettingsWriteBackupFile;
+    QAction* actionSettingsToggleDownloads;
     QAction* actionSettingsUseAnimation;
 };
 
