@@ -7,8 +7,6 @@
 #include "task.h"
 #include "vymmodel.h"
 
-extern QString flagsPath;
-
 TaskModel::TaskModel(QObject *parent)
     : QAbstractTableModel(parent)
 {
@@ -83,7 +81,7 @@ QVariant TaskModel::data(const QModelIndex &index, int role) const
             BranchItem *bi = tasks.at(index.row())->getBranch();
             QString s;
             if (bi)
-                s = bi->getHeading(); 
+                s = bi->getHeadingPlain();
             else
                 qDebug()<<"bi == NULL";
 
@@ -91,14 +89,14 @@ QVariant TaskModel::data(const QModelIndex &index, int role) const
             while ( l > 0 && bi->depth() >0 )
             {
                 bi = bi->parentBranch();
-                if (bi) s = bi->getHeading() + " -> " + s;
+                if (bi) s = bi->getHeadingPlain() + " -> " + s;
                 l--;
             }
             return s;
         }
     } else if (role == Qt::DecorationRole && index.column() == 1)
     {
-        return QIcon( flagsPath + "flag-" + t->getIconString() + ".png");
+        return QIcon(":/flag-" + t->getIconString() + ".png");
     }
     else // role != Qt::DisplayRole
     {
@@ -302,7 +300,7 @@ void TaskModel::recalcPriorities()
     foreach (Task *t,tasks)
     {   
 	t->setPriority (1-  minPrio + t->getPriority() );
-	emitDataChanged (t);
+	//emitDataChanged (t);
     }
 
     emit (layoutChanged() );
