@@ -27,6 +27,7 @@ public:
     Link (VymModel *m);
     virtual ~Link();
     virtual void init ();
+    VymModel* getModel();
     void setBeginBranch (BranchItem*);
     BranchItem* getBeginBranch();
     void setEndBranch   (BranchItem*);
@@ -40,6 +41,10 @@ public:
     void setPen (const QPen &p);
     QPen getPen();
     void setLinkType (const QString &s);
+    void setStyleBegin( const QString &s);
+    QString  getStyleBeginString();
+    void setStyleEnd( const QString &s);
+    QString  getStyleEndString();
     bool activate ();		
     void deactivate ();		
     XLinkState getState();
