@@ -36,6 +36,10 @@ void XLinkItem::init ()
     link=NULL;
 }
 
+void XLinkItem::clear() 
+{
+}
+
 void XLinkItem::setLink (Link *l)
 {
     link=l;
@@ -48,7 +52,6 @@ Link* XLinkItem::getLink ()
 
 void XLinkItem::updateXLink()
 {
-    qDebug()<<"XLI::updateXLink";
     if (link)
 	link->updateLink();
 }
@@ -60,6 +63,21 @@ MapObj* XLinkItem::getMO()
     return NULL;	
 }
 
+void XLinkItem::setSelection()
+{
+    if (link)
+    {
+	XLinkObj* xlo=(XLinkObj*)getMO();
+	if (xlo) 
+	{
+	    if (parentItem==link->getBeginBranch() )
+		xlo->setSelection(XLinkObj::C0);
+	    else if (parentItem==link->getEndBranch() )
+		xlo->setSelection(XLinkObj::C1);
+	}
+    }
+}
+
 BranchItem* XLinkItem::getPartnerBranch()
 {
     if (link && link->getBeginBranch() && link->getEndBranch())
