@@ -2,6 +2,8 @@
 #define XLINKOBJ_H
 
 #include <QPen>
+
+#include "arrowobj.h"
 #include "linkablemapobj.h"
 #include "mapobj.h"
 #include "xlink.h"
@@ -19,6 +21,12 @@ public:
     virtual ~XLinkObj ();
     virtual void init ();
     virtual QPointF getAbsPos();
+    void setStyleBegin(const QString &s);
+    void setStyleBegin(ArrowObj::OrnamentStyle os);
+    ArrowObj::OrnamentStyle getStyleBegin();
+    void setStyleEnd(const QString &s);
+    void setStyleEnd(ArrowObj::OrnamentStyle os);
+    ArrowObj::OrnamentStyle getStyleEnd();
     QPointF getBeginPos();
     QPointF getEndPos();
     virtual void move (QPointF p);
@@ -39,13 +47,15 @@ public:
     QPainterPath getClickPath();
 
 private:
-    enum StateVis {Hidden,Part,Full,FullShowControls};
+    enum StateVis {Hidden,OnlyBegin,OnlyEnd,Full,FullShowControls};
     StateVis stateVis;
     static int arrowSize;
     static int clickBorder;
     static int pointRadius;
     QPainterPath clickPath;
-    QGraphicsPolygonItem *poly;	    // Arrowhead, when one end is not visible
+    QGraphicsPolygonItem *poly;// Arrowhead, when one end is not visible
+    ArrowObj *pointerBegin;    // Arrowhead 
+    ArrowObj *pointerEnd;      // Arrowhead 
     QGraphicsPathItem *path;
     
     QPointF beginPos;
@@ -55,8 +65,6 @@ private:
     LinkableMapObj::Orientation   endOrient;
     QGraphicsEllipseItem *ctrl_p0;
     QGraphicsEllipseItem *ctrl_p1;
-    QGraphicsLineItem *ctrl_l0;
-    QGraphicsLineItem *ctrl_l1;
 
     CurrentSelection curSelection;
 
