@@ -3,7 +3,7 @@
 
 #include "xml-base.h"
 
-#include "noteobj.h"
+#include "vymnote.h"
 
 class BranchItem;
 class ImageItem;
@@ -25,6 +25,8 @@ private:
     int contentFilter;    
 public:
     bool startDocument();
+    bool startCDATA();
+    bool endCDATA();
     bool startElement ( const QString&, const QString&,
                         const QString& eName, const QXmlAttributes& atts ); 
     bool   endElement ( const QString&, const QString&, const QString& ); 
@@ -44,26 +46,26 @@ public:
 
 private:
     enum State 
-    { 
-	StateInit, 
-	StateMap, 
-	StateMapSelect, 
-	StateMapSetting,
-	StateMapSlide,
-	StateMapCenter, 
-	StateBranch, 
-	StateBranchXLink,	    // Obsolete
-	StateVymNote,
-	StateHtmlNote,		    // Obsolete >= 1.13.6
-	StateHtml, 
-	StateFrame,
-	StateStandardFlag,
-	StateNote,		    // Obsolete >= 1.4.6
-	StateImage,
-	StateHeading,
-	StateLink,
-	StateAttribute,
-	StateTask
+    {
+        StateInit,
+        StateMap,
+        StateMapSelect,
+        StateMapSetting,
+        StateMapSlide,
+        StateMapCenter,
+        StateBranch,
+        StateBranchXLink,	    // Obsolete
+        StateVymNote,
+        StateHtmlNote,		    // Obsolete >= 1.13.6
+        StateHtml,
+        StateFrame,
+        StateStandardFlag,
+        StateNote,		    // Obsolete >= 1.4.6
+        StateImage,
+        StateHeading,
+        StateLink,
+        StateAttribute,
+        StateTask
      };
 
      int branchesCounter;
@@ -71,13 +73,14 @@ private:
 
     State state;	     
     QList <State> stateStack;
-    NoteObj no;
+    VymText vymtext;
 
     BranchItem* lastBranch;
     ImageItem* lastImage;
     MapItem* lastMI;
     SlideItem *lastSlide;
     Task *lastTask;
+    QString lastSetting;
 
     bool useProgress;
 }; 
