@@ -4,7 +4,7 @@
 #include <QDebug>
 #include <QMessageBox>
 
-#include "process.h"
+#include "vymprocess.h"
 
 
 extern bool debug;
@@ -50,8 +50,9 @@ void XSLTProc::addOutput (const QString &s)
 void XSLTProc::process()
 {
     ShowTextDialog dia;
+    dia.useFixedFont (true);
     QStringList args;
-    Process *xsltProc=new Process ();
+    VymProcess *xsltProc=new VymProcess ();
 
     QStringList::Iterator itk;
     QStringList::Iterator itv=stringParamVal.begin();
